==> adgydeplugin-4.1.7.tar.gz: example/lib/uniqueevent.dart <==
import 'package:flutter/material.dart';
import 'package:adgydeplugin/adgydeplugin.dart';

class UniqueEvent extends StatefulWidget{
  @override
  State<StatefulWidget> createState() {
    // TODO: implement createState
    return UniqueEventState();
  }
}
class UniqueEventState extends State<UniqueEvent>{
  Adgydeplugin adgydesinstance=new Adgydeplugin();
  @override
  Widget build(BuildContext context) {

    return new Scaffold(
        appBar: new AppBar(
          title: new Text("AdGyde Sdk Example"),
        ),
        body: new Center(

            child: new Column(
              children: <Widget>[
                new RaisedButton(
                  textColor: Colors.white,
                  color: Colors.blue,
                  onPressed: onDailyUnique,
                  child: new Text("onDailyUnique"),
                ),
                new RaisedButton(
                  textColor: Colors.white,
                  color: Colors.blue,
                  //padding: const EdgeInsets.all(8.0),
                  onPressed: onPermanentUnique,
                  child: new Text("onPermanentUnique"),
                ),
                new RaisedButton(
                  textColor: Colors.white,
                  color: Colors.blue,
                  //padding: const EdgeInsets.all(8.0),
                  onPressed: onCustomUnique,
                  child: new Text("onCustomUnique"),
                ),

              ],
            )
        )
    );
  }

  /**
   * Daily Unique event allows to keep an event unique for current date
   * When user completes Game Stage
   */

  void onDailyUnique() {
    //The parameter being passed in unique event are in combination of ParameterName and Value
    var params={"stage":"stage1"};
    // Event is triggered with EventId and Parameters prepared above, the same are passed in this function
    adgydesinstance.daliyUnique("dailygamelevelcomplete", params);
  }

  /**
   * Permanent Unique event allows to keep an event unique for user lifetime
   */
  void onPermanentUnique() {
    //The parameter being passed in unique event are in combination of ParameterName and Value
    var params={"level":"level_1"};
    // Event is triggered with EventId and Parameters prepared above, the same are passed in this function
    adgydesinstance.permanentUnique("permanentgamelevelcomplete", params);
  }

  /**
   * Custom Unique event allows to keep an event unique for user defined time (hours)
   */
  void onCustomUnique() {
//The parameter being passed in unique event are in combination of ParameterName and Value
    var params={"level":"level_1"};
// Event is triggered with EventId and Parameters prepared above, the same are passed in this function
// The third parameter (3) specifies that the Event will not be counted again before 3 hours
    adgydesinstance.customUnique("customgamelevelcomplete", params, 3);

  }
}

==> adgydeplugin-4.2.4.tar.gz: example/lib/uniqueevent.dart <==
import 'package:flutter/material.dart';
import 'package:adgydeplugin/adgydeplugin.dart';

class UniqueEvent extends StatefulWidget{
  @override
  State<StatefulWidget> createState() {
    Adgydeplugin adgydesinstance = new Adgydeplugin();
    // TODO: implement createState
    adgydesinstance.setCurrentScreen("UniquePage");
    return UniqueEventState();
  }
}
class UniqueEventState extends State<UniqueEvent>{
  Adgydeplugin adgydesinstance = new Adgydeplugin();

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {

    return new Scaffold(
        appBar: new AppBar(
          title: new Text("Unique Page"),
        ),
        body: new Center(

            child: new Column(
              children: <Widget>[
                new RaisedButton(
                  textColor: Colors.white,
                  color: Colors.blue,
                  onPressed: onDailyUnique,
                  child: new Text("onDailyUnique"),
                ),
                new RaisedButton(
                  textColor: Colors.white,
                  color: Colors.blue,
                  //padding: const EdgeInsets.all(8.0),
                  onPressed: onPermanentUnique,
                  child: new Text("onPermanentUnique"),
                ),
                new RaisedButton(
                  textColor: Colors.white,
                  color: Colors.blue,
                  //padding: const EdgeInsets.all(8.0),
                  onPressed: onCustomUnique,
                  child: new Text("onCustomUnique"),
                ),

              ],
            )
        )
    );
  }

  /**
   * Daily Unique event allows to keep an event unique for current date
   * When user completes Game Stage
   */

  void onDailyUnique() {
    //The parameter being passed in unique event are in combination of ParameterName and Value
    var params={"stage":"stage1"};
    // Event is triggered with EventId and Parameters prepared above, the same are passed in this function
    adgydesinstance.daliyUnique("dailygamelevelcomplete", params);
  }

  /**
   * Permanent Unique event allows to keep an event unique for user lifetime
   */
  void onPermanentUnique() {
    //The parameter being passed in unique event are in combination of ParameterName and Value
    var params={"level":"level_1"};
    // Event is triggered with EventId and Parameters prepared above, the same are passed in this function
    adgydesinstance.permanentUnique("permanentgamelevelcomplete", params);
  }

  /**
   * Custom Unique event allows to keep an event unique for user defined time (hours)
   */
  void onCustomUnique() {
//The parameter being passed in unique event are in combination of ParameterName and Value
    var params={"level":"level_1"};
// Event is triggered with EventId and Parameters prepared above, the same are passed in this function
// The third parameter (3) specifies that the Event will not be counted again before 3 hours
    adgydesinstance.customUnique("customgamelevelcomplete", params, 3);

  }
}
